@@ -2,22 +2,28 @@ from .continuous import *
 from .discrete import *
 
 all_continuous = [
+    AsymmetricLaplace,
     Beta,
     BetaScaled,
     Cauchy,
     ChiSquared,
+    ExGaussian,
     Exponential,
     Gamma,
+    Gumbel,
     HalfCauchy,
     HalfNormal,
     HalfStudent,
     InverseGamma,
     Laplace,
+    Logistic,
     LogNormal,
+    Moyal,
     Normal,
     Pareto,
     SkewNormal,
     Student,
+    Triangular,
     TruncatedNormal,
     Uniform,
     VonMises,
