@@ -85,8 +85,7 @@ class AsymmetricLaplace(Continuous):
 
     def __init__(self, kappa=None, mu=None, b=None, q=None):
         super().__init__()
-        self.name = "asymmetriclaplace"
-        self.dist = stats.laplace_asymmetric
+        self.dist = copy(stats.laplace_asymmetric)
         self.support = (-np.inf, np.inf)
         self._parametrization(kappa, mu, b, q)
 
@@ -124,9 +123,9 @@ class AsymmetricLaplace(Continuous):
         return frozen
 
     def _update(self, kappa, mu, b):
-        self.kappa = kappa
-        self.mu = mu
-        self.b = b
+        self.kappa = float(kappa)
+        self.mu = float(mu)
+        self.b = float(b)
         self.q = self._to_q(self.kappa)
 
         if self.param_names[0] == "kappa":
@@ -204,8 +203,7 @@ class Beta(Continuous):
 
     def __init__(self, alpha=None, beta=None, mu=None, sigma=None, kappa=None):
         super().__init__()
-        self.name = "beta"
-        self.dist = stats.beta
+        self.dist = copy(stats.beta)
         self.support = (0, 1)
         self._parametrization(alpha, beta, mu, sigma, kappa)
 
@@ -267,8 +265,8 @@ class Beta(Continuous):
         return frozen
 
     def _update(self, alpha, beta):
-        self.alpha = alpha
-        self.beta = beta
+        self.alpha = float(alpha)
+        self.beta = float(beta)
         self.mu, self.sigma = self._to_mu_sigma(self.alpha, self.beta)
         self.kappa = self.mu * (1 - self.mu) / self.sigma**2 - 1
 
@@ -341,7 +339,6 @@ class BetaScaled(Continuous):
         self.beta = beta
         self.lower = lower
         self.upper = upper
-        self.name = "betascaled"
         self.dist = copy(stats.beta)
         self.support = (lower, upper)
         self._parametrization(self.alpha, self.beta, self.lower, self.upper)
@@ -360,12 +357,12 @@ class BetaScaled(Continuous):
 
     def _update(self, alpha, beta, lower=None, upper=None):
         if lower is not None:
-            self.lower = lower
+            self.lower = float(lower)
         if upper is not None:
-            self.upper = upper
+            self.upper = float(upper)
 
-        self.alpha = alpha
-        self.beta = beta
+        self.alpha = float(alpha)
+        self.beta = float(beta)
         self.params = (self.alpha, self.beta, self.lower, self.upper)
         self.support = self.lower, self.upper
         self._update_rv_frozen()
@@ -421,8 +418,7 @@ class Cauchy(Continuous):
 
     def __init__(self, alpha=None, beta=None):
         super().__init__()
-        self.name = "cauchy"
-        self.dist = stats.cauchy
+        self.dist = copy(stats.cauchy)
         self.support = (-np.inf, np.inf)
         self._parametrization(alpha, beta)
 
@@ -442,8 +438,8 @@ class Cauchy(Continuous):
         return frozen
 
     def _update(self, alpha, beta):
-        self.alpha = alpha
-        self.beta = beta
+        self.alpha = float(alpha)
+        self.beta = float(beta)
         self.params = (self.alpha, self.beta)
         self._update_rv_frozen()
 
@@ -494,8 +490,7 @@ class ChiSquared(Continuous):
     def __init__(self, nu=None):
         super().__init__()
         self.nu = nu
-        self.name = "chisquared"
-        self.dist = stats.chi2
+        self.dist = copy(stats.chi2)
         self.support = (0, np.inf)
         self._parametrization(nu)
 
@@ -504,7 +499,8 @@ class ChiSquared(Continuous):
         self.param_names = ("nu",)
         self.params_support = ((eps, np.inf),)
         self.params = (self.nu,)
-        self._update(self.nu)
+        if self.nu is not None:
+            self._update(self.nu)
 
     def _get_frozen(self):
         frozen = None
@@ -513,7 +509,7 @@ class ChiSquared(Continuous):
         return frozen
 
     def _update(self, nu):
-        self.nu = nu
+        self.nu = float(nu)
         self.params = (self.nu,)
         self._update_rv_frozen()
 
@@ -575,8 +571,7 @@ class ExGaussian(Continuous):
 
     def __init__(self, mu=None, sigma=None, nu=None):
         super().__init__()
-        self.name = "exgaussian"
-        self.dist = stats.exponnorm
+        self.dist = copy(stats.exponnorm)
         self.support = (-np.inf, np.inf)
         self._parametrization(mu, sigma, nu)
 
@@ -597,9 +592,9 @@ class ExGaussian(Continuous):
         return frozen
 
     def _update(self, mu, sigma, nu):
-        self.nu = nu
-        self.mu = mu
-        self.sigma = sigma
+        self.nu = float(nu)
+        self.mu = float(mu)
+        self.sigma = float(sigma)
         self.params = (self.mu, self.sigma, self.nu)
         self._update_rv_frozen()
 
@@ -647,8 +642,7 @@ class Exponential(Continuous):
     def __init__(self, lam=None):
         super().__init__()
         self.lam = lam
-        self.name = "exponential"
-        self.dist = stats.expon
+        self.dist = copy(stats.expon)
         self.support = (0, np.inf)
         self._parametrization(lam)
 
@@ -657,7 +651,8 @@ class Exponential(Continuous):
         self.params = (self.lam,)
         self.param_names = ("lam",)
         self.params_support = ((eps, np.inf),)
-        self._update(self.lam)
+        if self.lam is not None:
+            self._update(self.lam)
 
     def _get_frozen(self):
         frozen = None
@@ -666,7 +661,7 @@ class Exponential(Continuous):
         return frozen
 
     def _update(self, lam):
-        self.lam = lam
+        self.lam = float(lam)
         self.params = (self.lam,)
         self._update_rv_frozen()
 
@@ -734,8 +729,7 @@ class Gamma(Continuous):
 
     def __init__(self, alpha=None, beta=None, mu=None, sigma=None):
         super().__init__()
-        self.name = "gamma"
-        self.dist = stats.gamma
+        self.dist = copy(stats.gamma)
         self.support = (0, np.inf)
         self._parametrization(alpha, beta, mu, sigma)
 
@@ -777,8 +771,8 @@ class Gamma(Continuous):
         return frozen
 
     def _update(self, alpha, beta):
-        self.alpha = alpha
-        self.beta = beta
+        self.alpha = float(alpha)
+        self.beta = float(beta)
         self.mu, self.sigma = self._to_mu_sigma(self.alpha, self.beta)
 
         if self.param_names[0] == "alpha":
@@ -840,8 +834,7 @@ class Gumbel(Continuous):
 
     def __init__(self, mu=None, beta=None):
         super().__init__()
-        self.name = "gumbel"
-        self.dist = stats.gumbel_r
+        self.dist = copy(stats.gumbel_r)
         self.support = (-np.inf, np.inf)
         self._parametrization(mu, beta)
 
@@ -851,7 +844,8 @@ class Gumbel(Continuous):
         self.params = (self.mu, self.beta)
         self.param_names = ("mu", "beta")
         self.params_support = ((-np.inf, np.inf), (eps, np.inf))
-        self._update(self.mu, self.beta)
+        if (self.mu and self.beta) is not None:
+            self._update(self.mu, self.beta)
 
     def _get_frozen(self):
         frozen = None
@@ -860,8 +854,8 @@ class Gumbel(Continuous):
         return frozen
 
     def _update(self, mu, beta):
-        self.mu = mu
-        self.beta = beta
+        self.mu = float(mu)
+        self.beta = float(beta)
         self.params = (self.mu, self.beta)
         self._update_rv_frozen()
 
@@ -909,8 +903,7 @@ class HalfCauchy(Continuous):
 
     def __init__(self, beta=None):
         super().__init__()
-        self.name = "halfcauchy"
-        self.dist = stats.halfcauchy
+        self.dist = copy(stats.halfcauchy)
         self.support = (0, np.inf)
         self._parametrization(beta)
 
@@ -919,7 +912,8 @@ class HalfCauchy(Continuous):
         self.params = (self.beta,)
         self.param_names = ("beta",)
         self.params_support = ((eps, np.inf),)
-        self._update(self.beta)
+        if self.beta is not None:
+            self._update(self.beta)
 
     def _get_frozen(self):
         frozen = None
@@ -928,7 +922,7 @@ class HalfCauchy(Continuous):
         return frozen
 
     def _update(self, beta):
-        self.beta = beta
+        self.beta = float(beta)
         self.params = (self.beta,)
         self._update_rv_frozen()
 
@@ -987,8 +981,7 @@ class HalfNormal(Continuous):
 
     def __init__(self, sigma=None, tau=None):
         super().__init__()
-        self.name = "halfnormal"
-        self.dist = stats.halfnorm
+        self.dist = copy(stats.halfnorm)
         self.support = (0, np.inf)
         self._parametrization(sigma, tau)
 
@@ -1015,7 +1008,7 @@ class HalfNormal(Continuous):
         return frozen
 
     def _update(self, sigma):
-        self.sigma = sigma
+        self.sigma = float(sigma)
         self.tau = to_precision(sigma)
 
         if self.param_names[0] == "sigma":
@@ -1093,7 +1086,6 @@ class HalfStudent(Continuous):
 
     def __init__(self, nu=None, sigma=None, lam=None):
         super().__init__()
-        self.name = "halfstudent"
         self.dist = _HalfStudent
         self.support = (0, np.inf)
         self._parametrization(nu, sigma, lam)
@@ -1124,8 +1116,8 @@ class HalfStudent(Continuous):
         return frozen
 
     def _update(self, nu, sigma):
-        self.nu = nu
-        self.sigma = sigma
+        self.nu = float(nu)
+        self.sigma = float(sigma)
         self.lam = to_precision(sigma)
 
         if self.param_names[1] == "sigma":
@@ -1272,8 +1264,7 @@ class InverseGamma(Continuous):
 
     def __init__(self, alpha=None, beta=None, mu=None, sigma=None):
         super().__init__()
-        self.name = "inversegamma"
-        self.dist = stats.invgamma
+        self.dist = copy(stats.invgamma)
         self.support = (0, np.inf)
         self._parametrization(alpha, beta, mu, sigma)
 
@@ -1304,8 +1295,14 @@ class InverseGamma(Continuous):
         return alpha, beta
 
     def _to_mu_sigma(self, alpha, beta):
-        mu = beta / (alpha - 1)
-        sigma = beta / ((alpha - 1) * (alpha - 2) ** 0.5)
+        if alpha > 1:
+            mu = beta / (alpha - 1)
+        else:
+            mu = None
+        if alpha > 2:
+            sigma = beta / ((alpha - 1) * (alpha - 2) ** 0.5)
+        else:
+            sigma = None
         return mu, sigma
 
     def _get_frozen(self):
@@ -1315,8 +1312,8 @@ class InverseGamma(Continuous):
         return frozen
 
     def _update(self, alpha, beta):
-        self.alpha = alpha
-        self.beta = beta
+        self.alpha = float(alpha)
+        self.beta = float(beta)
         self.mu, self.sigma = self._to_mu_sigma(self.alpha, self.beta)
 
         if self.param_names[0] == "alpha":
@@ -1373,8 +1370,7 @@ class Laplace(Continuous):
 
     def __init__(self, mu=None, b=None):
         super().__init__()
-        self.name = "laplace"
-        self.dist = stats.laplace
+        self.dist = copy(stats.laplace)
         self.support = (-np.inf, np.inf)
         self._parametrization(mu, b)
 
@@ -1394,8 +1390,8 @@ class Laplace(Continuous):
         return frozen
 
     def _update(self, mu, b):
-        self.mu = mu
-        self.b = b
+        self.mu = float(mu)
+        self.b = float(b)
         self.params = (self.mu, self.b)
         self._update_rv_frozen()
 
@@ -1448,9 +1444,7 @@ class Logistic(Continuous):
 
     def __init__(self, mu=None, s=None):
         super().__init__()
-        self.name = "logistic"
-
-        self.dist = stats.logistic
+        self.dist = copy(stats.logistic)
         self.support = (-np.inf, np.inf)
         self._parametrization(mu, s)
 
@@ -1460,7 +1454,8 @@ class Logistic(Continuous):
         self.params = (self.mu, self.s)
         self.param_names = ("mu", "s")
         self.params_support = ((-np.inf, np.inf), (eps, np.inf))
-        self._update(self.mu, self.s)
+        if (self.mu and self.s) is not None:
+            self._update(self.mu, self.s)
 
     def _get_frozen(self):
         frozen = None
@@ -1469,8 +1464,8 @@ class Logistic(Continuous):
         return frozen
 
     def _update(self, mu, s):
-        self.mu = mu
-        self.s = s
+        self.mu = float(mu)
+        self.s = float(s)
         self.params = (self.mu, self.s)
         self._update_rv_frozen()
 
@@ -1528,8 +1523,7 @@ class LogNormal(Continuous):
 
     def __init__(self, mu=None, sigma=None):
         super().__init__()
-        self.name = "lognormal"
-        self.dist = stats.lognorm
+        self.dist = copy(stats.lognorm)
         self.support = (0, np.inf)
         self._parametrization(mu, sigma)
 
@@ -1549,8 +1543,8 @@ class LogNormal(Continuous):
         return frozen
 
     def _update(self, mu, sigma):
-        self.mu = mu
-        self.sigma = sigma
+        self.mu = float(mu)
+        self.sigma = float(sigma)
         self.params = (self.mu, self.sigma)
         self._update_rv_frozen()
 
@@ -1609,8 +1603,7 @@ class Moyal(Continuous):
 
     def __init__(self, mu=None, sigma=None):
         super().__init__()
-        self.name = "moyal"
-        self.dist = stats.moyal
+        self.dist = copy(stats.moyal)
         self.support = (-np.inf, np.inf)
         self._parametrization(mu, sigma)
 
@@ -1630,8 +1623,8 @@ class Moyal(Continuous):
         return frozen
 
     def _update(self, mu, sigma):
-        self.mu = mu
-        self.sigma = sigma
+        self.mu = float(mu)
+        self.sigma = float(sigma)
         self.params = (self.mu, self.sigma)
         self._update_rv_frozen()
 
@@ -1695,8 +1688,7 @@ class Normal(Continuous):
 
     def __init__(self, mu=None, sigma=None, tau=None):
         super().__init__()
-        self.name = "normal"
-        self.dist = stats.norm
+        self.dist = copy(stats.norm)
         self.support = (-np.inf, np.inf)
         self._parametrization(mu, sigma, tau)
 
@@ -1727,8 +1719,8 @@ class Normal(Continuous):
         return frozen
 
     def _update(self, mu, sigma):
-        self.mu = mu
-        self.sigma = sigma
+        self.mu = float(mu)
+        self.sigma = float(sigma)
         self.tau = to_precision(sigma)
 
         if self.param_names[1] == "sigma":
@@ -1783,8 +1775,7 @@ class Pareto(Continuous):
 
     def __init__(self, alpha=None, m=None):
         super().__init__()
-        self.name = "pareto"
-        self.dist = stats.pareto
+        self.dist = copy(stats.pareto)
         self.support = (0, np.inf)
         self._parametrization(alpha, m)
 
@@ -1804,9 +1795,9 @@ class Pareto(Continuous):
         return frozen
 
     def _update(self, alpha, m):
-        self.alpha = alpha
-        self.m = m
-        self.support = (m, np.inf)
+        self.alpha = float(alpha)
+        self.m = float(m)
+        self.support = (self.m, np.inf)
         self.params = (self.alpha, self.m)
         self._update_rv_frozen()
 
@@ -1875,8 +1866,7 @@ class SkewNormal(Continuous):
 
     def __init__(self, mu=None, sigma=None, alpha=None, tau=None):
         super().__init__()
-        self.name = "skewnormal"
-        self.dist = stats.skewnorm
+        self.dist = copy(stats.skewnorm)
         self.support = (-np.inf, np.inf)
         self._parametrization(mu, sigma, alpha, tau)
 
@@ -1908,9 +1898,9 @@ class SkewNormal(Continuous):
         return frozen
 
     def _update(self, mu, sigma, alpha):
-        self.mu = mu
-        self.sigma = sigma
-        self.alpha = alpha
+        self.mu = float(mu)
+        self.sigma = float(sigma)
+        self.alpha = float(alpha)
         self.tau = to_precision(sigma)
 
         if self.param_names[1] == "sigma":
@@ -1986,8 +1976,7 @@ class Student(Continuous):
 
     def __init__(self, nu=None, mu=None, sigma=None, lam=None):
         super().__init__()
-        self.name = "student"
-        self.dist = stats.t
+        self.dist = copy(stats.t)
         self.support = (-np.inf, np.inf)
         self.params_support = ((eps, np.inf), (-np.inf, np.inf), (eps, np.inf))
         self._parametrization(nu, mu, sigma, lam)
@@ -2020,9 +2009,9 @@ class Student(Continuous):
         return frozen
 
     def _update(self, nu, mu, sigma):
-        self.nu = nu
-        self.mu = mu
-        self.sigma = sigma
+        self.nu = float(nu)
+        self.mu = float(mu)
+        self.sigma = float(sigma)
         self.lam = to_precision(sigma)
 
         if self.param_names[2] == "sigma":
@@ -2098,8 +2087,7 @@ class Triangular(Continuous):
 
     def __init__(self, lower=None, c=None, upper=None):
         super().__init__()
-        self.name = "triangular"
-        self.dist = stats.triang
+        self.dist = copy(stats.triang)
         self.support = (-np.inf, np.inf)
         self._parametrization(lower, c, upper)
 
@@ -2122,9 +2110,9 @@ class Triangular(Continuous):
         return frozen
 
     def _update(self, lower, c, upper):
-        self.lower = lower
-        self.c = c
-        self.upper = upper
+        self.lower = float(lower)
+        self.c = float(c)
+        self.upper = float(upper)
         self.support = (self.lower, self.upper)
         self.params = (self.lower, self.c, self.upper)
         self._update_rv_frozen()
@@ -2188,8 +2176,7 @@ class TruncatedNormal(Continuous):
 
     def __init__(self, mu=None, sigma=None, lower=None, upper=None):
         super().__init__()
-        self.name = "truncatednormal"
-        self.dist = stats.truncnorm
+        self.dist = copy(stats.truncnorm)
         self._parametrization(mu, sigma, lower, upper)
 
     def _parametrization(self, mu=None, sigma=None, lower=None, upper=None):
@@ -2222,12 +2209,12 @@ class TruncatedNormal(Continuous):
 
     def _update(self, mu, sigma, lower=None, upper=None):
         if lower is not None:
-            self.lower = lower
+            self.lower = float(lower)
         if upper is not None:
-            self.upper = upper
+            self.upper = float(upper)
 
-        self.mu = mu
-        self.sigma = sigma
+        self.mu = float(mu)
+        self.sigma = float(sigma)
         self.params = (self.mu, self.sigma, self.lower, self.upper)
         self.support = (self.lower, self.upper)
         self._update_rv_frozen()
@@ -2278,8 +2265,7 @@ class Uniform(Continuous):
 
     def __init__(self, lower=None, upper=None):
         super().__init__()
-        self.name = "uniform"
-        self.dist = stats.uniform
+        self.dist = copy(stats.uniform)
         self._parametrization(lower, upper)
 
     def _parametrization(self, lower=None, upper=None):
@@ -2293,10 +2279,10 @@ class Uniform(Continuous):
         if upper is None:
             self.upper = np.inf
         self.support = (self.lower, self.upper)
-        self.dist.a = self.lower
-        self.dist.b = self.upper
         if (lower and upper) is not None:
             self._update(lower, upper)
+            self.dist.a = self.lower
+            self.dist.b = self.upper
         else:
             self.lower = lower
             self.upper = upper
@@ -2308,8 +2294,8 @@ class Uniform(Continuous):
         return frozen
 
     def _update(self, lower, upper):
-        self.lower = lower
-        self.upper = upper
+        self.lower = float(lower)
+        self.upper = float(upper)
         self.params = (self.lower, self.upper)
         self.support = (self.lower, self.upper)
         self._update_rv_frozen()
@@ -2365,15 +2351,14 @@ class VonMises(Continuous):
 
     def __init__(self, mu=None, kappa=None):
         super().__init__()
-        self.name = "vonmises"
-        self.dist = stats.vonmises
+        self.dist = copy(stats.vonmises)
         self._parametrization(mu, kappa)
 
     def _parametrization(self, mu=None, kappa=None):
         self.mu = mu
         self.kappa = kappa
         self.param_names = ("mu", "kappa")
-        self.params_support = ((-np.inf, np.inf), (eps, np.inf))
+        self.params_support = ((-np.pi, np.pi), (eps, np.inf))
         self.support = (-np.pi, np.pi)
         if (mu and kappa) is not None:
             self._update(mu, kappa)
@@ -2385,8 +2370,8 @@ class VonMises(Continuous):
         return frozen
 
     def _update(self, mu, kappa):
-        self.mu = mu
-        self.kappa = kappa
+        self.mu = float(mu)
+        self.kappa = float(kappa)
         self.params = (self.mu, self.kappa)
         self._update_rv_frozen()
 
@@ -2441,8 +2426,7 @@ class Wald(Continuous):
 
     def __init__(self, mu=None, lam=None):
         super().__init__()
-        self.name = "wald"
-        self.dist = stats.invgauss
+        self.dist = copy(stats.invgauss)
         self.support = (0, np.inf)
         self._parametrization(mu, lam)
 
@@ -2461,8 +2445,8 @@ class Wald(Continuous):
         return frozen
 
     def _update(self, mu, lam):
-        self.mu = mu
-        self.lam = lam
+        self.mu = float(mu)
+        self.lam = float(lam)
         self.params = (self.mu, self.lam)
         self._update_rv_frozen()
 
@@ -2514,8 +2498,7 @@ class Weibull(Continuous):
 
     def __init__(self, alpha=None, beta=None):
         super().__init__()
-        self.name = "weibull"
-        self.dist = stats.weibull_min
+        self.dist = copy(stats.weibull_min)
         self.support = (0, np.inf)
         self._parametrization(alpha, beta)
 
@@ -2534,8 +2517,8 @@ class Weibull(Continuous):
         return frozen
 
     def _update(self, alpha, beta):
-        self.alpha = alpha
-        self.beta = beta
+        self.alpha = float(alpha)
+        self.beta = float(beta)
         self.params = (self.alpha, self.beta)
         self._update_rv_frozen()
 
