@@ -4,6 +4,7 @@
 """
 Discrete probability distributions.
 """
+from copy import copy
 import logging
 from math import ceil, floor
 
@@ -58,8 +59,7 @@ class Binomial(Discrete):
 
     def __init__(self, n=None, p=None):
         super().__init__()
-        self.name = "binomial"
-        self.dist = stats.binom
+        self.dist = copy(stats.binom)
         self.support = (0, np.inf)
         self._parametrization(n, p)
 
@@ -80,7 +80,7 @@ class Binomial(Discrete):
 
     def _update(self, n, p):
         self.n = int(n)
-        self.p = p
+        self.p = float(p)
         self.params = (self.n, self.p)
         self.support = (0, self.n)
         self._update_rv_frozen()
@@ -137,8 +137,7 @@ class DiscreteUniform(Discrete):
 
     def __init__(self, lower=None, upper=None):
         super().__init__()
-        self.name = "discreteuniform"
-        self.dist = stats.randint
+        self.dist = copy(stats.randint)
         self._parametrization(lower, upper)
 
     def _parametrization(self, lower=None, upper=None):
@@ -249,8 +248,7 @@ class NegativeBinomial(Discrete):
 
     def __init__(self, mu=None, alpha=None, p=None, n=None):
         super().__init__()
-        self.name = "negativebinomial"
-        self.dist = stats.nbinom
+        self.dist = copy(stats.nbinom)
         self.support = (0, np.inf)
         self._parametrization(mu, alpha, p, n)
 
@@ -290,8 +288,8 @@ class NegativeBinomial(Discrete):
         return frozen
 
     def _update(self, mu, alpha):
-        self.mu = mu
-        self.alpha = alpha
+        self.mu = float(mu)
+        self.alpha = float(alpha)
         self.p, self.n = self._to_p_n(self.mu, self.alpha)
 
         if self.param_names[0] == "mu":
@@ -350,8 +348,7 @@ class Poisson(Discrete):
     def __init__(self, mu=None):
         super().__init__()
         self.mu = mu
-        self.name = "poisson"
-        self.dist = stats.poisson
+        self.dist = copy(stats.poisson)
         self.support = (0, np.inf)
         self._parametrization(mu)
 
@@ -370,7 +367,7 @@ class Poisson(Discrete):
         return frozen
 
     def _update(self, mu):
-        self.mu = mu
+        self.mu = float(mu)
         self.params = (self.mu,)
         self._update_rv_frozen()
 
