@@ -30,3 +30,11 @@ def test_continuous_plot_pdf_cdf_ppf(two_dist, kwargs):
         a_dist.plot_cdf(**kwargs)
         kwargs.pop("support", None)
         a_dist.plot_ppf(**kwargs)
+
+
+def test_plot_interactive():
+    for idx, distribution in enumerate(pz.distributions.__all__):
+        dist = getattr(pz.distributions, distribution)
+        kind = ["pdf", "cdf", "ppf"][idx % 3]
+        fixed_lim = ["auto", "both"][idx % 2]
+        dist().plot_interactive(kind=kind, fixed_lim=fixed_lim)
